@@ -1,6 +1,6 @@
 package Chemistry::File::SDF;
-$VERSION = '0.18';
-# $Id: SDF.pm,v 1.7 2005/01/27 19:06:34 itubert Exp $
+$VERSION = '0.21';
+# $Id: SDF.pm,v 1.10 2009/05/10 19:51:50 itubert Exp $
 
 use base "Chemistry::File";
 use Chemistry::Mol;
@@ -32,7 +32,7 @@ Chemistry::File::SDF - MDL Structure Data File reader/writer
 
     # Low level interface (one at a time)
     # create reader
-    my $reader = Chemistry::Mol->read('myfile.sdf');
+    my $reader = Chemistry::Mol->file('myfile.sdf');
     $reader->open('<');
     while (my $mol = $reader->read_mol($reader->fh)) {
         # do something with $mol
@@ -59,20 +59,6 @@ This module is part of the PerlMol project, L<http://www.perlmol.org>.
 
 =cut
 
-sub parse_string1 {
-    my ($self, $string, %opts) = @_;
-    my @mols;
-
-    $string =~ s/\r\n?/\n/g; # normalize EOL
-    my @mol_strings = split /\$\$\$\$\n/, $string;
-    for my $mol_string (@mol_strings) {
-        my $mol = Chemistry::File::MDLMol->parse_string($mol_string, %opts, _must_override => 0);
-        push @mols, $mol;
-        $self->parse_data($mol, $mol_string);
-    }
-    @mols;
-}
-
 sub slurp_mol {
     my ($self, $fh, %opts) = @_;
     return if $fh->eof;
@@ -179,7 +165,7 @@ Also note that SDF data field names are considered to be case-sensitive.
 
 =head1 VERSION
 
-0.18
+0.21
 
 =head1 SEE ALSO
 
@@ -197,7 +183,7 @@ Ivan Tubert-Brohman <itub@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005 Ivan Tubert-Brohman. All rights reserved. This program is
+Copyright (c) 2009 Ivan Tubert-Brohman. All rights reserved. This program is
 free software; you can redistribute it and/or modify it under the same terms as
 Perl itself.
 
